from typing import Optional


def recurring_fibonacci_number(number: int) -> Optional[int]:
    if number < 0:
        return None
    elif number <= 1:
        return number
    else:
        return recurring_fibonacci_number(number - 1) + recurring_fibonacci_number(number - 2)



from typing import List
from .fib_number import recurring_fibonacci_number


def calculate_numbers(numbers: List[int]) -> List[int]:
    return [recurring_fibonacci_number(number=i) for i in numbers]



import argparse
from felix_fib_py.fib_calcs.fib_number import recurring_fibonacci_number


def fib_numb() -> None:
    parser = argparse.ArgumentParser(description='Calculate Fibonacci numbers')
    parser.add_argument(
        '--number',
        action='store',
        type=int,
        required=True,
        help='Fibonacci number to be calculated'
    )
    args = parser.parse_args()
    print(f"Your Fibonacci number is: {recurring_fibonacci_number(number=args.number)}")



from setuptools import find_packages, setup


with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="felix_fib_py",
    version="0.0.1",
    author="Felix",
    author_email="417055+CodeTalks@users.noreply.github.com",
    description="Calculates a Fibonacci number",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/CodeTalks/felix-fib-py",
    install_requires=[],
    packages=find_packages(exclude=("tests",)),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3',
    tests_require=['pytest'],
    entry_points={
        'console_scripts': [
            'fib-number = felix_fib_py.cmd.fib_numb:fib_numb',
        ]
    }
)
